// import peerDepsExternal from "rollup-plugin-peer-deps-external";
import resolve from "@rollup/plugin-node-resolve";
import commonjs from "@rollup/plugin-commonjs";
import typescript from "rollup-plugin-typescript2";
import postcss from "rollup-plugin-postcss";
import vuePlugin from 'rollup-plugin-vue'
import copy from 'rollup-plugin-copy'
import replace from "@rollup/plugin-replace";

const packageJson = require("./package.json");

export default {
  input: "src/index.js",
  output: [
    {
      dir: 'dist',
      format: "umd",
      sourcemap: true,
    },
  ],
  
  plugins: [
    replace({
      'hash': packageJson.hash,
      'version': packageJson.version,
      delimiters: ['{{{', '}}}'],
    }),
    replace({
      'process.env.NODE_ENV': JSON.stringify( process.env.NODE_ENV ),
    }),
    resolve({
      browser: true
    }),
    vuePlugin(),
    commonjs(),
    typescript({ 
      useTsconfigDeclarationDir: true,
      check: false 
    }),
    postcss(),
    copy({
      targets: [
        {
          src: 'statics',
          dest: 'dist/'
        }
      ]
    })
  ]
};
